@@ -47,7 +47,7 @@ def _clean_db(session) -> bool:
             num_deleted += 1
             log.debug(f"Deleted {pic.absolute_path} from db.")
         if count % 1000 == 0:
-            log.debug(f"Checked {count} db entries for missing hdd files.")
+            log.info(f"Checked {count} db entries for missing hdd files.")
     log.info(f"Deleted {num_deleted} entries from db.")
     return num_deleted > 0
 
@@ -93,7 +93,7 @@ def _add_and_update_pics(pic_file_gen, session) -> bool:
             session.commit()
             num_changed += 1
             if count % 1000 == 0:
-                log.debug(f"Checked {count} files for necessary db updates.")
+                log.info(f"Checked {count} files for necessary db updates.")
         except Exception as e:
             log.error(
                 f"Exception while trying to update db with {pic_file.path}.", exc_info=e
